/* 
 * File:   EEPROM.h
 * Author: chengo_cc
 *
 * Created on 30 December 2015, 10:47 PM
 */

#ifndef EEPROM_H
//------------------------------------------------------------------------------
#include "prototypes.h"
//------------------------------------------------------------------------------
void EEPROM_write(int address,char data)
{
  while( EEPROM_busy() == 1 );

  //Set write enable latch
  CS = 0;
  SPI_write(WREN);
  CS = 1; //Latch-Enabled. use isWriteEn() if you want to verify

  //Start Write sequence(only occurs when/if Write latch is Enanled)
  CS = 0;
  SPI_write(WRITE);
  SPI_write(address>>8);
  SPI_write(address);
  SPI_write(data);
  CS = 1;
}
//------------------------------------------------------------------------------
char EEPROM_read(int address)
{
  while( EEPROM_busy() == 1 ); //Wait for previous Write/Read operations to finish

  CS = 0;
  SPI_write(READ);
  SPI_write(address>>8);     //Upper Byte
  SPI_write(address);        //Lower Byte
  char data = SPI_read(0);
  CS = 1;

  return data;
}
//------------------------------Used as a flag----------------------------------
char EEPROM_status()
{
  CS = 0;
  SPI_write(RDSR);         //Intsruction: Read Status register of the EEPROM
  char status = SPI_read(0) ;   //Send a Dummy parameter to read. Thus ANY int number is valid
  CS = 1;

  return status;
}
//------------------------------------------------------------------------------
char EEPROM_busy()
{
  char busy = EEPROM_status();

  return (busy & 0x01); //LSB is Write-In-Process (WIP) bit. When Set, a write is in progress, when Clear, no write is in progress
}
//------------------------------------------------------------------------------
char EEPROM_wrEnable()
{
  char isWrite = EEPROM_status();

  return (isWrite & 0x02); //Bit 2 is the Write Enable Latch (WEL) bit and indicates the status of the write enable latch
}
//------------------------------------------------------------------------------
#define	EEPROM_H

#ifdef	__cplusplus
extern "C" {
#endif




#ifdef	__cplusplus
}
#endif

#endif	/* EEPROM_H */